/**
 * 共用 loader 或 plugin 配置参数
 */

const path = require('path')
const fs = require('fs')
const { getMode, getSourceMap, getProjectRoot } = require('../common/util')

module.exports = () => {
  const mode = getMode()
  const sourceMap = !!getSourceMap()
  const projectRoot = getProjectRoot()

  const babelLoaderOptions = {
    presets: [
      [
        '@babel/preset-env', {
          targets: { 'browsers': ['android >= 4'] }
        }
      ]
    ],
    plugins: [
      ['@babel/plugin-proposal-class-properties', { loose: true }],
      '@babel/plugin-syntax-dynamic-import',
      ['@babel/plugin-transform-runtime', { corejs: 2 }]
    ]
  }

  const cssLoaderOptions = { sourceMap }

  const postcssLoaderOptions = {
    sourceMap,
    plugins: () => [
      require('postcss-preset-env')({
        stage: 0,
        browsers: ['> 0.01%']
      })
    ]
  }

  const sassLoaderOptions = { sourceMap }

  const globalSassResources = path.resolve(projectRoot, 'src/style/var.scss')
  const sassResourcesOptions = fs.existsSync(globalSassResources) ? { resources: [ globalSassResources ] } : void 0

  const miniCssOptions = {
    hmr: mode === 'development',
    reloadAll: true,
    publicPath: '../'
  }

  return {
    babelLoaderOptions,
    cssLoaderOptions,
    postcssLoaderOptions,
    sassLoaderOptions,
    sassResourcesOptions,
    miniCssOptions
  }
}
